@@ -4,7 +4,7 @@ giorgi.tdph.maxim <- function(x, theta0, nTD, nPH, event, ehazard, ehazardInt,
                               P, p, k, nrowx, IntGL, nghq = nghq, cpti, cptj, cst, boundmin,
                               boundmax, Int.chazard, Int.FDbase, Int.SDbase,
                               int, control, speedy =  FALSE, pophaz, add.rmap,
-                              add.rmap.cut) {browser()
+                              add.rmap.cut) {
   control.iter.max <- control$iter.max
   control.eps <- control$eps
   name.bs <- dimnames(x)[[2]]
@@ -30,7 +30,7 @@ giorgi.tdph.maxim <- function(x, theta0, nTD, nPH, event, ehazard, ehazardInt,
       stop("Please check the specification of pophaz")
     }
 
-browser()
+
 if (rescale) {
   if (nTD >= 1) {
     name[6:(5 + (5 * nTD))] <- sapply(1:nTD,
