@@ -4,11 +4,17 @@
 #' @description Function to plot excess hazard or net survival
 #'
 #'
-#' @param x An object of class predxhaz
+#' @param x An object of class predxhaz or coercible
 #'
 #' @param what allow to choose between excess hazard
 #'      (\code{what="hazard"}) or net survival (\code{what="survival"}).
 #'
+#' @param add if \code{TRUE}, add to an existing plot.
+#'
+#' @param step if \code{TRUE} and \code{what="hazard"}, the excess hazard is
+#' plotted by a piecewise constant function (step function). By default, it is
+#'  set to \code{TRUE} when the baseline hazard is piecewise constant.
+#'
 #' @param ... additional arguments affecting the plot function
 #'
 #' @keywords plot.predxhaz
@@ -101,37 +107,36 @@
 #'
 #' par(old.par)
 #' }
-
-plot.predxhaz <- function(x, what = "survival", ...){
-   if (any(class(x) == "predxhaz")) {
-    time <- sapply(1:length(x), function(i)unique(x[[i]]$times.pts))
-    if (what == "survival") {
-      survival <- sapply(1:length(x), function(i) mean(x[[i]]$survival))
-      plot(time, survival, type = "l",...)
-      grid()
-
-    } else if (what == "hazard") {
-      hazard <-
-        sapply(1:length(x), function(i) {
-          (sum(x[[i]]$hazard * x[[i]]$survival) / sum(x[[i]]$survival))
-        })
-
-
-      if (attr(x, "baseline") == "constant") {
-        plot(time, hazard, type = "s",...)
-
-        grid()
-
-         }else {
-        plot(time, hazard, type = "l",...)
-        grid()
-      }
-    } else if (what == "beta") {
-      stop("not yet implemented")
-    }
-
-  } else {
-    stop("not yet implemented")
+#'
+#'
+#'
+plot.predxhaz <- function(x, what = c("survival", "hazard"),
+                          add = FALSE, step = NULL, ...) {
+  if (!inherits(x, "predxhaz")) {
+    x <- try(as.predxhaz(x), silent = TRUE)
+    if (inherits(x, "try-error"))
+      stop("Object is not 'predxhaz' and cannot be coerced via as.predxhaz().", call. = FALSE)
   }
+  what <- match.arg(what)
+
+  time <- x$time
+  y    <- if (what == "survival") x$survival else x$hazard
+
+  ok <- is.finite(time) & is.finite(y)
+  if (!any(ok)) stop("No finite values in 'time' / '", what, "'.", call. = FALSE)
+  time <- time[ok]; y <- y[ok]
+  o <- order(time); time <- time[o]; y <- y[o]
+
+  if (is.null(step)) {
+    step <- (what == "hazard" && identical(attr(x, "baseline", TRUE), "constant"))
+  }
+  type_arg <- if (isTRUE(step)) "s" else "l"
+
+  if (!add) {
+    plot(time, y, type = type_arg, ...)
+  } else {
+    lines(time, y, type = type_arg, ...)
+  }
+  invisible(x)
 
 }
