@@ -246,7 +246,7 @@
 #' fit.corrected1 <- xhaz(formula = Surv(time_year, status) ~ agec + race,
 #'                        data = simuData,
 #'                        ratetable = survexp.us,
-#'                        interval = c(0, NA, NA, NA, NA, NA, 6),
+#'                        interval = c(0, NA, NA, NA, 6),
 #'                        rmap = list(age = 'age', sex = 'sex', year = 'date'),
 #'                        baseline = "constant", pophaz = "corrected",
 #'                        add.rmap = "race")
@@ -282,7 +282,7 @@
 #' #                    baseline excess hazard.
 #'
 #'
-#' fitphBS <- xhaz(formula = Surv(time_year, status) ~ agec + race,
+#' fitphBS <- xhaz(formula = Surv(time_year, status) ~ agec,
 #'                 data = simuData,
 #'                 ratetable = survexp.us,
 #'                 interval = c(0, NA, NA, 6),
@@ -360,7 +360,7 @@ xhaz <- function(formula = formula(data),
                    print_stepwise = FALSE
                  ),
                  interval,
-                 ratedata = sys.parent(),
+                 ratedata = NULL,
                  subset,
                  na.action,
                  init,
@@ -388,7 +388,6 @@ xhaz <- function(formula = formula(data),
     }
     else
       rcall <- NULL
-
     breakpoint_with_cut(
       formula = formula,
       data = data,
@@ -463,7 +462,6 @@ xhaz <- function(formula = formula(data),
     }
     else
       rcall <- NULL
-
     without_breakpoint_without_cut(
       formula = formula,
       data = data,
